@@ -1,8 +1,10 @@
 from geopy.geocoders.bing import Bing
 from geopy.geocoders.google import Google
+from geopy.geocoders.googlev3 import GoogleV3
 from geopy.geocoders.dot_us import GeocoderDotUS
 from geopy.geocoders.geonames import GeoNames
 from geopy.geocoders.wiki_gis import MediaWiki
 from geopy.geocoders.wiki_semantic import SemanticMediaWiki
 from geopy.geocoders.yahoo import Yahoo
 from geopy.geocoders.openmapquest import OpenMapQuest
+from geopy.geocoders.mapquest import MapQuest
