@@ -28,6 +28,8 @@ class GeoNames(Geocoder):
         self.url = "http://ws.geonames.org/searchJSON?%s"
     
     def geocode(self, string, exactly_one=True):
+        if isinstance(string, unicode):
+            string = string.encode('utf-8')
         params = {
             'q': string
         }
